==> qt3d-opensource-src_5.12.8+dfsg.orig.tar.xz: qt3d-everywhere-src-5.12.8/tests/auto/core/common/qbackendnodetester.h <==
/****************************************************************************
**
** Copyright (C) 2016 Klaralvdalens Datakonsult AB (KDAB).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the Qt3D module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL3$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see http://www.qt.io/terms-conditions. For further
** information use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPLv3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or later as published by the Free
** Software Foundation and appearing in the file LICENSE.GPL included in
** the packaging of this file. Please review the following information to
** ensure the GNU General Public License version 2.0 requirements will be
** met: http://www.gnu.org/licenses/gpl-2.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QT3DCORE_QBACKENDNODETESTER_H
#define QT3DCORE_QBACKENDNODETESTER_H

#include <QObject>
#include <Qt3DCore/qnodeid.h>
#include <Qt3DCore/qscenechange.h>
#include <Qt3DCore/qnodecreatedchange.h>

QT_BEGIN_NAMESPACE

namespace Qt3DCore {

class QBackendNode;
class QNode;

class QBackendNodeTester : public QObject
{
    Q_OBJECT
public:
    explicit QBackendNodeTester(QObject *parent = 0);

    // Proxies to allow test classes to call private methods on QBackendNode
    void setPeerId(QBackendNode *backend, QNodeId id);
    void simulateInitialization(QNode *frontend, QBackendNode *backend);
    void sceneChangeEvent(QBackendNode *backend, const Qt3DCore::QSceneChangePtr &e);
    Qt3DCore::QNodeCreatedChangeBasePtr creationChange(QNode *frontend) const;
};

} // namespace Qt3DCore

QT_END_NAMESPACE

#endif // QT3DCORE_QBACKENDNODETESTER_H

==> qt3d-opensource-src_5.15.15+dfsg.orig.tar.xz: qt3d-everywhere-src-5.15.15/tests/auto/core/common/qbackendnodetester.h <==
/****************************************************************************
**
** Copyright (C) 2016 Klaralvdalens Datakonsult AB (KDAB).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the Qt3D module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL3$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see http://www.qt.io/terms-conditions. For further
** information use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPLv3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or later as published by the Free
** Software Foundation and appearing in the file LICENSE.GPL included in
** the packaging of this file. Please review the following information to
** ensure the GNU General Public License version 2.0 requirements will be
** met: http://www.gnu.org/licenses/gpl-2.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QT3DCORE_QBACKENDNODETESTER_H
#define QT3DCORE_QBACKENDNODETESTER_H

#include <QObject>
#include <Qt3DCore/qnodeid.h>
#include <Qt3DCore/qscenechange.h>
#include <Qt3DCore/qnodecreatedchange.h>
#include <Qt3DCore/qnode.h>

QT_BEGIN_NAMESPACE

namespace Qt3DCore {

class QBackendNode;

class QBackendNodeTester : public QObject
{
    Q_OBJECT
public:
    explicit QBackendNodeTester(QObject *parent = 0);

    // Proxies to allow test classes to call private methods on QBackendNode
    void setPeerId(QBackendNode *backend, QNodeId id);
    void sceneChangeEvent(QBackendNode *backend, const Qt3DCore::QSceneChangePtr &e);
    Qt3DCore::QNodeCreatedChangeBasePtr creationChange(QNode *frontend) const;

    template<class Backend>
    void simulateInitializationSync(QNode *frontend, Backend *backend)
    {
        Q_ASSERT(frontend);
        Q_ASSERT(backend);

        backend->setPeerId(frontend->id());
        backend->setEnabled(frontend->isEnabled());
        backend->syncFromFrontEnd(frontend, true);
    }

    void simulateInitialization(QNode *frontend, QBackendNode *backend);
};

} // namespace Qt3DCore

QT_END_NAMESPACE

#endif // QT3DCORE_QBACKENDNODETESTER_H
